From 893534d3b5753b110b84144596da6c6d0815c1cc Mon Sep 17 00:00:00 2001
From: marshmellow42 <marshmellowrf@gmail.com>
Date: Mon, 20 Feb 2017 15:06:22 -0500
Subject: [PATCH 1/1] speed up the em4x05 cmds by only getting 6k...

samples back
---
 armsrc/lfops.c     | 2 +-
 client/cmdlfem4x.c | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/armsrc/lfops.c b/armsrc/lfops.c
index 87b21efc..cfe032fc 100644
--- a/armsrc/lfops.c
+++ b/armsrc/lfops.c
@@ -1628,7 +1628,7 @@ void EM4xReadWord(uint8_t Address, uint32_t Pwd, uint8_t PwdMode) {
 	SendForward(fwd_bit_count);
 
 	// Now do the acquisition
-	DoAcquisition_default(0,TRUE);
+	doT55x7Acquisition(6000);
 	
 	FpgaWriteConfWord(FPGA_MAJOR_MODE_OFF); // field off
 	LED_A_OFF();
diff --git a/client/cmdlfem4x.c b/client/cmdlfem4x.c
index 6781b03d..e0c415bb 100644
--- a/client/cmdlfem4x.c
+++ b/client/cmdlfem4x.c
@@ -534,8 +534,8 @@ bool EM4x05testDemodReadData(uint32_t *word, bool readCmd) {
 	// skip first two 0 bits as they might have been missed in the demod
 	uint8_t preamble[] = {0,0,1,0,1,0};
 	size_t startIdx = 0;
-	// set size to 15 to only test first 9 positions for the preamble
-	size_t size = (15 > DemodBufferLen) ? DemodBufferLen : 15;
+	// set size to 20 to only test first 14 positions for the preamble
+	size_t size = (20 > DemodBufferLen) ? DemodBufferLen : 20;
 
 	//test preamble
 	if ( !onePreambleSearch(DemodBuffer, preamble, sizeof(preamble), size, &startIdx) ) {
-- 
2.39.5